#
# spec file for package libcgroup
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname	libcgroup1
Name:           libcgroup
Version:        0.41
Release:        7.4
Summary:        Control groups management tools
License:        LGPL-2.1
Group:          System/Management
Url:            http://sourceforge.net/projects/libcg/
Source:         http://sourceforge.net/projects/libcg/files/%{name}/v%{version}/%{name}-%{version}.tar.bz2
Source3:        sysconfig.cgred
Source99:       baselibs.conf
Patch5:         initd_cgconfig.patch
Patch6:         initd_cgred.patch
Patch9:         do-not-version-pam-module.patch
Patch10:        cgconfig-Do-not-overwrite-defaultcgroup-configuratio.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pam-devel
BuildRequires:  pkg-config
Requires:       insserv
Requires(post):	%insserv_prereq %fillup_prereq
Requires:       pam
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Control groups, a new kernel feature in Linux 2.6.24 provides a file
system interface to manipulate and control the details on task grouping
including creation of new task groups (control groups), permission
handling and task assignment.

%package -n %{lname}
Summary:        Control groups management library
Group:          System/Libraries

%description -n %{lname}
Control groups, a new kernel feature in Linux 2.6.24 provides a file
system interface to manipulate and control the details on task grouping
including creation of new task groups (control groups), permission
handling and task assignment.

%package devel
Summary:        Control groups management tools devel package
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
Control groups, a new kernel feature in Linux 2.6.24 provides a file
system interface to manipulate and control the details on task grouping
including creation of new task groups (control groups), permission
handling and task assignment.

%package tools
Summary:        Control groups management tools
Group:          System/Management
Requires(post): %fillup_prereq
Requires(post): %insserv_prereq
# Added for openSUSE 12.3 to aid the solver.
Provides:       libcgroup1:%{_bindir}/cgexec

%description tools
Control groups, a new kernel feature in Linux 2.6.24 provides a file
system interface to manipulate and control the details on task grouping
including creation of new task groups (control groups), permission
handling and task assignment.

%prep
%setup -q
%patch5 -p1
%patch6 -p1
%patch9 -p1
%patch10 -p1
autoreconf -fvi

%build
%configure \
    --disable-silent-rules \
    --enable-pam-module-dir=/%{_lib}/security \
    --enable-initscript-install
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags} INITSCRIPTDIR=%{buildroot}/%{_sysconfdir}/init.d/
find %{buildroot} -type f -name "*.la" -delete -print
rm -f %{buildroot}/%{_lib}/security/*.so.*
mkdir -p %{buildroot}/%{_localstatedir}/adm/fillup-templates/
install -m 644 %{SOURCE3} %{buildroot}/%{_localstatedir}/adm/fillup-templates/sysconfig.cgred

# FIXME: migrate to systemd
ln -s %{_sysconfdir}/init.d/cgred %{buildroot}/%{_sbindir}/rccgred
ln -s %{_sysconfdir}/init.d/cgconfig %{buildroot}/%{_sbindir}/rccgconfig

# remove setuid
chmod u-s %{buildroot}/%{_bindir}/cgexec

# move lib to rootfs
libcgso=$(basename %{buildroot}/%{_libdir}/libcgroup.so.*.*.*)
mkdir -p %{buildroot}/%{_lib}
mv -f %{buildroot}/%{_libdir}/libcgroup.so.*.*.* %{buildroot}/%{_lib}
rm -f %{buildroot}/%{_libdir}/libcgroup.so.1
ln -sf $libcgso %{buildroot}/%{_lib}/libcgroup.so.1
ln -sf ../../%{_lib}/$libcgso %{buildroot}/%{_libdir}/libcgroup.so

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%preun tools
%stop_on_removal cgred cgconfig

%post tools
%{fillup_and_insserv -f cgconfig}
%{fillup_and_insserv -n cgred}

%postun tools
%restart_on_update cgconfig cgred
%insserv_cleanup

%files -n %{lname}
%defattr(-,root,root)
/%{_lib}/libcgroup.so.*

%files tools
%defattr(-,root,root)
%doc COPYING
%doc README
%doc README_daemon
%doc samples/cgconfig.conf
%doc samples/cgrules.conf
%{_sysconfdir}/init.d/cgconfig
%{_sysconfdir}/init.d/cgred
%{_bindir}/cg*
%{_bindir}/ls*
%{_sbindir}/cg*
%{_sbindir}/rccgred
%{_sbindir}/rccgconfig
/%{_lib}/security/pam_cgroup.so
%{_localstatedir}/adm/fillup-templates/sysconfig.cgred
%{_mandir}/man[^3]/*

%files devel
%defattr(-,root,root)
%{_libdir}/libcgroup.so
%{_includedir}/libcgroup.h
%dir %{_includedir}/libcgroup
%{_includedir}/libcgroup/*.h
%{_libdir}/pkgconfig/libcgroup.pc

%changelog
* Wed Jan 14 2015 tcech@suse.cz
- add Require for post install scriptlets (bnc#912531)
* Wed Jan 14 2015 mhocko@suse.de
- cgconfig-Do-not-overwrite-defaultcgroup-configuratio.patch - cgconfig:
  Do not overwrite defaultcgroup configuration (bnc#912487)
* Tue Jan 13 2015 tchvatal@suse.com
- Cleanup with spec-cleaner
- Version bump to 0.41 - no changelog
- Add fillup/insserv prereqs bnc#912531
* Fri Jan 10 2014 mhocko@suse.com
- package upgraded from 0.37 to 0.41.rc1
- libcgroup-man_pages.patch: removed because obsoleted by 41b1e43155831
- initd_cgconfig-read-correctly-defaultcgroup.patch: removed because
  obsoleted by 9659403b713f9
* Thu May  2 2013 mhocko@suse.cz
- do-not-version-pam-module.patch: fix an invalid link to pam_cgroup.so.0.0.0
  and do not build cgroup pam module as a versioned shared object (bnc#817533)
* Tue Nov 27 2012 jengelh@inai.de
- Remove redundant/obsolete sections from specfile
- Follow shlib packaging guidelines; libcgroup1 ought to only have
  the library, move the rest into libcgroup-tools.
* Thu Nov 22 2012 mhocko@suse.cz
- initd_cgconfig-read-correctly-defaultcgroup.patch: fix defaultcgroup
  detection (bnc#790934)
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Oct 31 2011 jslaby@suse.de
- fix rpmlint warnings
* Wed Aug 31 2011 jslaby@suse.de
- don't use /var/lock/subsys/ (bnc#714631)
* Fri Jun 24 2011 jslaby@suse.de
- kill _service
* Wed May 11 2011 pth@suse.de
- Enhance the man pages.
* Thu Mar  3 2011 jslaby@suse.de
- update to 0.37.1
  - get rid of the local patches
  - fix buffer overflow (bnc#675506, CVE-2011-1006)
  - verify the sender of netlink messages (bnc#675048, CVE-2011-1022)
  - check length of netlink addresses (CVE-2011-1022)
  - improve handling of out-of-memory.
  - --sticky option works for setuid/setgid
* Wed Jan 12 2011 jslaby@suse.de
- sync cgconfig and cgred init.d scripts with upstream
- man pages fixes
* Tue Jan  4 2011 jslaby@suse.de
- update cgconfig and cgred init.d scripts
- fix segfault in cgconfigparser
* Mon Dec 20 2010 jslaby@suse.de
- update to 0.37
  - init scripts fixes
  - add new tools (scripts need not to do much work)
  - fixes in what tools and scripts return
  - many memory leaks fixed
  - other small fixes
* Mon Jul  5 2010 jslaby@suse.de
- update to 0.36.2 final
* Fri Jun  4 2010 kay.sievers@novell.com
- update to 0.36.2.rc
  - install pkg-config file
  - do not call exit() on error
- drop all patches which are upstream now or no longer needed
- install library in the rootfs, not in /usr
- enable verbose build
* Fri Feb  5 2010 jslaby@suse.de
- really fail to start (forgotten %%patch3)
* Thu Feb  4 2010 jslaby@suse.de
- fail to start when a parsing error occurs (bnc#576932)
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Tue Aug 18 2009 jslaby@suse.de
- update init scripts. cgred moved to /usr/sbin/
* Wed Jun 24 2009 sbrabec@suse.cz
- Supplement pam-32bit/pam-64bit in baselibs.conf (bnc#354164).
* Mon May  4 2009 jslaby@suse.de
- update to 0.33
- refresh patches and make them -p1
- add pam module and manpages
* Fri Jan  2 2009 jslaby@suse.de
- Update to 0.32.2
- Fix devel package group (to Development/Libraries)
- Fix cgred init script
- Update cgconfig init script to create a default cgroup (bnc#458611)
* Thu Nov  6 2008 jslaby@suse.cz
- Update to 0.32.1
- Add init.d scripts configuration samples.
* Mon Oct 20 2008 schwab@suse.de
- Fix invalid use of sigaction.
* Wed Oct 15 2008 kukuk@suse.de
- Fix typo
* Tue Oct 14 2008 kukuk@suse.de
- Fix name of devel package
* Wed Oct  1 2008 jslaby@suse.cz
- initial package
